@@ -1,5 +1,6 @@
-import datetime
+import os
 from time import sleep
+import sys
 import warnings
 
 import click
@@ -9,19 +10,17 @@ from rich.table import Table
 from rich.syntax import Syntax
 from rich.progress import Progress, BarColumn
 
-from dask.utils import format_bytes, format_time_ago
-from distributed.core import Status
-from distributed.cli.utils import check_python_3
-from distributed.utils import typename
-
 from . import __version__
 from .utils import loop
 from .discovery import (
-    discover_clusters,
     discover_cluster_names,
     list_discovery_methods,
 )
 from .lifecycle import create_cluster, get_cluster, delete_cluster, get_snippet
+from .renderables import generate_table
+
+from .tui import DaskCtlTUI
+
 from . import config  # noqa
 
 console = Console()
@@ -43,15 +42,29 @@ def autocomplete_cluster_names(ctx, args, incomplete):
     return loop.run_sync(_autocomplete_cluster_names)
 
 
-@click.group()
+@click.command(
+    context_settings=dict(
+        ignore_unknown_options=True,
+        allow_extra_args=True,
+    )
+)
 def cli():
-    """daskctl controls Dask clusters."""
-    pass
+    """[deprecated] use `dask cluster` instead of `daskctl`."""
+
+    click.echo(
+        "The command `daskctl` has been deprecated, please use `dask cluster` instead."
+    )
+    sys.exit(1)
 
 
-@cli.group()
+@click.group()
 def cluster():
-    """Cluster commands."""
+    """Manage dask clusters.
+
+    Create, List, Scale and Delete your dask clusters with dask-ctl.
+
+    See https://dask-ctl.readthedocs.io/en/latest/cli.html for more info.
+    """
     pass
 
 
@@ -60,16 +73,13 @@ def cluster():
 def create(spec_file_path):
     """Create a Dask cluster from a spec file."""
 
-    async def _create():
-        try:
-            cluster = await create_cluster(spec_file_path)
-        except Exception:
-            click.echo("Failed to create cluster.")
-            raise click.Abort()
-        else:
-            click.echo(f"Created cluster {cluster.name}.")
-
-    loop.run_sync(_create)
+    try:
+        cluster = create_cluster(spec_file_path)
+    except Exception:
+        click.echo("Failed to create cluster.")
+        raise click.Abort()
+    else:
+        click.echo(f"Created cluster {cluster.name}.")
 
 
 @cluster.command()
@@ -78,74 +88,15 @@ def list(discovery=None):
     """List Dask clusters.
 
     DISCOVERY can be optionally set to restrict which discovery method to use.
-    Run `daskctl list-discovery` for all available options.
+    Run `dask cluster discovery list` for all available options.
     """
 
     async def _list():
-        table = Table(box=box.SIMPLE)
-        table.add_column("Name", style="cyan", no_wrap=True)
-        table.add_column("Address")
-        table.add_column("Type")
-        table.add_column("Discovery")
-        table.add_column("Workers")
-        table.add_column("Threads")
-        table.add_column("Memory")
-        table.add_column("Created")
-        table.add_column("Status")
 
         with console.status("[bold green]Discovering clusters...") as status:
-            discovery_methods = list_discovery_methods()
-            for discovery_method in discovery_methods:
-                status.update(f"[bold green]Discovering {discovery_method}s...")
-                if discovery_methods[discovery_method]["enabled"] and (
-                    discovery is None or discovery == discovery_method
-                ):
-                    try:
-                        async for cluster in discover_clusters(
-                            discovery=discovery_method
-                        ):
-                            try:
-                                workers = cluster.scheduler_info["workers"].values()
-                            except KeyError:
-                                workers = []
-                            try:
-                                created = format_time_ago(
-                                    datetime.datetime.fromtimestamp(
-                                        float(cluster.scheduler_info["started"])
-                                    )
-                                )
-                            except KeyError:
-                                created = "Unknown"
-
-                            cluster_status = cluster.status.name.title()
-                            if cluster.status == Status.created:
-                                cluster_status = f"[yellow]{cluster_status}[/yellow]"
-                            elif cluster.status == Status.running:
-                                cluster_status = f"[green]{cluster_status}[/green]"
-                            else:
-                                cluster_status = f"[red]{cluster_status}[/red]"
-
-                            table.add_row(
-                                cluster.name,
-                                cluster.scheduler_address,
-                                typename(type(cluster)),
-                                discovery_method,
-                                str(len(workers)),
-                                str(sum(w["nthreads"] for w in workers)),
-                                format_bytes(sum([w["memory_limit"] for w in workers])),
-                                created,
-                                cluster_status,
-                            )
-                    except Exception:
-                        if discovery is None:
-                            console.print(
-                                f":warning: Discovery {discovery_method} failed. "
-                                f"Run `daskctl cluster list {discovery_method}` for more info.",
-                                style="yellow",
-                            )
-                        else:
-                            console.print_exception(show_locals=True)
-                            raise click.Abort()
+            table = await generate_table(
+                discovery=discovery, status=status, console=console
+            )
 
         console.print(table)
 
@@ -153,13 +104,13 @@ def list(discovery=None):
 
 
 @cluster.command()
-@click.argument("name", autocompletion=autocomplete_cluster_names)
+@click.argument("name", shell_complete=autocomplete_cluster_names)
 @click.argument("n-workers", type=int)
 def scale(name, n_workers):
     """Scale a Dask cluster.
 
     NAME is the name of the cluster to scale.
-    Run `daskctl list` for all available options.
+    Run `dask cluster list` for all available options.
 
     N_WORKERS is the number of workers to scale to.
 
@@ -219,14 +170,14 @@ def scale(name, n_workers):
 
 
 @cluster.command()
-@click.argument("name", autocompletion=autocomplete_cluster_names)
+@click.argument("name", shell_complete=autocomplete_cluster_names)
 def delete(
     name,
 ):
     """Delete a Dask cluster.
 
     NAME is the name of the cluster to delete.
-    Run `daskctl list` for all available options.
+    Run `dask cluster list` for all available options.
 
     """
     try:
@@ -239,14 +190,14 @@ def delete(
 
 
 @cluster.command()
-@click.argument("name", autocompletion=autocomplete_cluster_names)
+@click.argument("name", shell_complete=autocomplete_cluster_names)
 def snippet(
     name,
 ):
     """Get code snippet for connecting to a cluster.
 
     NAME is the name of the cluster to get a snippet for.
-    Run `daskctl list` for all available options.
+    Run `dask cluster list` for all available options.
 
     """
     try:
@@ -263,9 +214,9 @@ def snippet(
         console.print(snip)
 
 
-@cli.group()
+@cluster.group()
 def discovery():
-    """Discovery commands."""
+    """Cluster discovery subcommands."""
     pass
 
 
@@ -320,14 +271,29 @@ def disable_discovery(name):
     )
 
 
-@cli.command()
+@cluster.command()
 def version():
-    """Show the daskctl version."""
-    click.echo(__version__)
+    """Show the dask-ctl version."""
+    click.echo(f"dask-ctl: {__version__}")
+
+
+@cluster.command()
+@click.option("--debug/--no-debug", default=False)
+def ui(debug):
+    """Open the Dask Control Text UI."""
+    from textual.features import parse_features
+
+    features = set(parse_features(os.environ.get("TEXTUAL", "")))
+    if debug:
+        features.add("debug")
+        features.add("devtools")
+
+    os.environ["TEXTUAL"] = ",".join(sorted(features))
+
+    DaskCtlTUI().run()
 
 
 def daskctl():
-    check_python_3()
     cli()
 
 
